@@ -34,5 +34,5 @@ def main():
         groups = {s.split('_')[0] for s in rec.samples
                   if not any(a is None for a in rec.samples[s].allele_indices)
                   if sum(rec.samples[s].allele_indices) > 0}
-        if len(groups) == 1 and (groups.pop() in args.groups):
-            vcf_out.write(rec)
+        if (len(groups) == 1) and (args.groups is None or groups.pop() in args.groups):
+                vcf_out.write(rec)
